import * as React from 'react'

import { makeStyles, createStyles, Theme } from '@material-ui/core/styles'
import { Typography, Box, Button, Toolbar, Paper, Hidden } from '@material-ui/core'

import LogoImage from '../images/logo.svg';

const useStyles = makeStyles((theme: Theme) => createStyles({
  toolbar: {
    padding: '30px 40px',
  },
  logo: {
    width: '180px',
    marginRight: '20px',
  },
  appName: {
    flex: 1,
  },
  body: {
    backgroundColor: theme.palette.background.default,
    maxWidth: '850px',
    marginLeft: 'auto',
    marginRight: 'auto',
    padding: '10px',
  },
  title: {
    paddingTop:'60px',
  },
  description: {
    maxWidth: '600px',
    paddingTop: '30px',
    lineHeight: 1.2,
    color: theme.palette.grey[700],
  },
}), { name: 'SigninBanner' });

export interface SignInBannerProps {
  /** Callback indicating user clicked sign in button */
  onSignIn?: () => void;

  /** Is user engaged in a sign in process? */
  isSigningIn?: boolean;
}

/**
 * Page which encourages users to sign in to the site.
 */
export const SignInBanner: React.FunctionComponent<SignInBannerProps> = ({
  onSignIn = () => null,
  isSigningIn = false,
}) => {
  const classes = useStyles()

  const signInButton = (
    <Button color="primary" onClick={onSignIn} disabled={isSigningIn} variant="contained">
      Sign in with Raven
    </Button>
  );

  return (
    <Box>
      <Toolbar className={classes.toolbar}>
        <img src={LogoImage} className={classes.logo} alt="Cambridge University Logo"/>
        <Typography variant='h6' className={classes.appName}>
          Information Asset Register
        </Typography>
        <Hidden smDown={true}>
          { signInButton }
        </Hidden>
      </Toolbar>
      <Paper elevation={0} classes={{root: classes.body}}>
        <Typography variant="h4" className={classes.title}>
          Information asset register:<br /> record details of information held by your institution
        </Typography>
        <Typography className={classes.description}>
          You must record details of certain information assets (databases, lists or other collections
          of data) held by your institution — you were originally asked to do this by 30 April 2018
          but please continue to add and edit entries as necessary.
        </Typography>
        <Typography className={classes.description}>
          This will help the University meet its duties under the General Data Protection Regulation
          which became law on 25 May 2018.
        </Typography>
        <Typography className={classes.description}>
          Use the information asset register (IAR) to add, edit and view the details of these
          information assets. You cannot upload the data itself.
        </Typography>
        <Typography className={classes.description}>
          { signInButton }
        </Typography>
      </Paper>
    </Box>
  );
};

export default SignInBanner;
