import * as React from 'react'
import {
  Box,
  CircularProgress,
} from '@material-ui/core'

import SignInBanner from '../components/SignInBanner'
import UnauthorisedBanner from '../components/UnauthorisedBanner'

import { useAuthenticationState } from '../api'

/**
 * A component which only shows its children if the current user is signed in.
 */
export const SignInRequired: React.FunctionComponent = ({ children }) => {
  const { isSigningIn, signIn, signOut, profile } = useAuthenticationState();
  const isSignedIn = Boolean(profile);
  const isAuthorised = Boolean(profile && profile.isAuthorised)

  return <>
    {
      (!signIn || isSigningIn) && !isSignedIn &&
      <Box p={2} textAlign="center">
        <CircularProgress />
      </Box>
    }
    {
      signIn && !isSigningIn && !isSignedIn &&
      <SignInBanner isSigningIn={isSigningIn} onSignIn={signIn} />
    }
    {
      isSignedIn && !isAuthorised &&
      <UnauthorisedBanner onSignOut={signOut} profile={profile} />
    }
    {
      isSignedIn && isAuthorised && children
    }
  </>;
};

export default SignInRequired;
